@@ -61,9 +61,15 @@ class MainWindow(QMainWindow):
             f = open(userInfoPath, "r+")
             Person.userID = f.readline()
             f.close()
-            self.nextPG = MoodAnalyzerPg()
-            self.nextPG.show()
-            self.hide()
+            print(Person.userID)
+            if not Person.userID:
+                self.nextPG = UserLoginPG()
+                self.nextPG.show()
+                self.hide()
+            else:
+                self.nextPG = MoodAnalyzerPg()
+                self.nextPG.show()
+                self.hide()
         else:
             self.nextPG = UserLoginPG()
             self.nextPG.show()
